Module map

Module map 

Structs

AuthorityMap
Authority map: which steps have access to which secrets/identities.
MapRow
A row in the authority map: one step and its authority grants.

Functions

authority_map
Build the authority map from a graph.
job_names
Distinct job names attached to Step nodes via META_JOB_NAME. Sorted alphabetically — used to render helpful error messages when a user passes --job <name> that doesn’t match any step.
render_dot
Render the authority graph as a Graphviz DOT digraph string.
render_map
Render the authority map as a formatted table string.
render_mermaid
Render the authority graph as a Mermaid flowchart LR (parity with render_dot’s rankdir=LR).