Module map
taudit_
core
1.0.8
Module map
Module Items
Structs
Functions
In crate taudit_
core
taudit_core
Module
map
Structs

Authority
Map
Authority map: which steps have access to which secrets/identities.
MapRow
A row in the authority map: one step and its authority grants.
Functions

authority_
map
Build the authority map from a graph.
job_
names
Distinct job names attached to Step nodes via
META_JOB_NAME
. Sorted alphabetically — used to render helpful error messages when a user passes
--job <name>
that doesn’t match any step.
render_
dot
Render the authority graph as a Graphviz DOT digraph string.
render_
map
Render the authority map as a formatted table string.
render_
mermaid
Render the authority graph as a Mermaid
flowchart LR
(parity with
render_dot
’s
rankdir=LR
).